@@ -10,6 +10,7 @@ const BUILD_FOLDER: &str = "target/fuzzcheck";
 pub fn launch_executable(
     target_name: &str,
     args: &Arguments,
+    cargo_args: &[String],
     stdio: impl Fn() -> Stdio,
 ) -> std::io::Result<process::Child> {
     let args = string_from_args(args);
@@ -17,9 +18,10 @@ pub fn launch_executable(
         .env("FUZZCHECK_ARGS", args)
         .env(
             "RUSTFLAGS",
-            "-Zinstrument-coverage=except-unused-functions --cfg fuzzing",
+            "-Zinstrument-coverage=except-unused-functions -Zno-profiler-runtime --cfg fuzzing -Ctarget-cpu=native -Ccodegen-units=1",
         )
         .arg("test")
+        .args(cargo_args)
         .args(["--target", TARGET])
         .arg("--release")
         .args(["--target-dir", BUILD_FOLDER])
@@ -35,7 +37,12 @@ pub fn launch_executable(
     Ok(child)
 }
 
-pub fn input_minify_command(target_name: &str, args: &Arguments, stdio: &impl Fn() -> Stdio) -> std::io::Result<()> {
+pub fn input_minify_command(
+    target_name: &str,
+    args: &Arguments,
+    cargo_args: &[String],
+    stdio: &impl Fn() -> Stdio,
+) -> std::io::Result<()> {
     let mut config = args.clone();
     let file_to_minify = if let FuzzerCommand::MinifyInput { input_file } = config.command {
         input_file
@@ -52,6 +59,7 @@ pub fn input_minify_command(target_name: &str, args: &Arguments, stdio: &impl Fn
 
     let _ = std::fs::create_dir(&artifacts_folder);
     config.artifacts_folder = Some(artifacts_folder.clone());
+    config.stop_after_first_failure = true;
 
     fn simplest_input_file(folder: &Path) -> Option<PathBuf> {
         let files_with_complexity = std::fs::read_dir(folder)
@@ -77,23 +85,17 @@ pub fn input_minify_command(target_name: &str, args: &Arguments, stdio: &impl Fn
         input_file: simplest.clone(),
     };
 
-    let child = launch_executable(target_name, &config, stdio)?;
+    let child = launch_executable(target_name, &config, cargo_args, stdio)?;
     let o = child.wait_with_output()?;
 
     assert!(!o.status.success());
 
-    // hjhjb.minifyd/hshs.parent() != hjhjb.minifyd/ -> copy hshs to hjhjb.minifyd/hshs
-    //let destination = artifacts_folder.join(arguments.input_file.file_name());
-    // if arguments.input_file.unwrap().parent() != Some(artifacts_folder.as_path()) {
-    //     std::fs::copy(arguments.input_file, artifacts_folder.to_owned() + arguments.input_file);
-    // }
-
     loop {
         simplest = simplest_input_file(&artifacts_folder).unwrap_or_else(|| simplest.clone());
         config.command = FuzzerCommand::MinifyInput {
             input_file: simplest.clone(),
         };
-        let mut c = launch_executable(target_name, &config, Stdio::inherit)?;
+        let mut c = launch_executable(target_name, &config, cargo_args, Stdio::inherit)?;
         c.wait()?;
     }
 }
@@ -155,8 +157,11 @@ pub fn string_from_args(args: &Arguments) -> String {
     s.push_str(" ");
 
     s.push_str(&format!("--{} {} ", MAX_INPUT_CPLX_FLAG, args.max_input_cplx as usize));
-
-    s.push_str(&format!("--{} {} ", TIMEOUT_FLAG, args.timeout));
+    s.push_str(&format!("--{} {} ", MAX_DURATION_FLAG, args.maximum_duration.as_secs()));
+    s.push_str(&format!("--{} {} ", MAX_ITERATIONS_FLAG, args.maximum_iterations));
+    if args.stop_after_first_failure {
+        s.push_str(&format!("--{} ", STOP_AFTER_FIRST_FAILURE_FLAG));
+    }
 
     if let Some(socket_address) = args.socket_address {
         s.push_str(&format!("--{} {} ", SOCK_ADDR_FLAG, socket_address,));
